@@ -28,6 +28,16 @@
 #ifdef HAVE_CONFIG_H
 #include <kdrive-config.h>
 #endif
+/*
+ * including some server headers (like kdrive-config.h)
+ * might define the macro _XSERVER64
+ * on 64 bits machines. That macro must _NOT_ be defined for Xlib
+ * client code, otherwise bad things happen.
+ * So let's undef that macro if necessary.
+ */
+#ifdef _XSERVER64
+#undef _XSERVER64
+#endif
 #include <X11/Xutil.h>
 #include <X11/Xlibint.h>
 #include <X11/extensions/Xvlib.h>
@@ -475,10 +485,8 @@ ephyrHostEncodingsDelete (EphyrHostEncoding *a_encodings,
     if (!a_encodings)
         return ;
     for (i=0; i < a_num_encodings; i++) {
-        if (a_encodings[i].name) {
-            xfree (a_encodings[i].name) ;
-            a_encodings[i].name = NULL ;
-        }
+        xfree (a_encodings[i].name) ;
+        a_encodings[i].name = NULL ;
     }
     xfree (a_encodings) ;
 }
