@@ -37,7 +37,6 @@
 #endif
 #include "win.h"
 #include "winmsg.h"
-#include "safeAlpha.h"	
 
 
 #ifdef XWIN_MULTIWINDOWEXTWM
@@ -59,8 +58,10 @@ winMWExtWMProcs = {
   winMWExtWMDamageRects,
 #endif
   winMWExtWMRootlessSwitchWindow,
-  NULL,//winWMExtWMDoReorderWindow,
-  
+  NULL,//winMWExtWMDoReorderWindow,
+  NULL,//winMWExtWMHideWindow,
+  NULL,//winMWExtWMUpdateColorMap,
+
   NULL,//winMWExtWMCopyBytes,
   NULL,//winMWExtWMFillBytes,
   NULL,//winMWExtWMCompositePixels,
@@ -238,6 +239,16 @@ winScreenInit (int index,
   else
     winErrorFVerb(2, "winScreenInit - Using software cursor\n");  
 
+  /*
+     Note the screen origin in a normalized coordinate space where (0,0) is at the top left
+     of the native virtual desktop area
+  */
+  dixScreenOrigins[index].x = pScreenInfo->dwInitialX - GetSystemMetrics(SM_XVIRTUALSCREEN);
+  dixScreenOrigins[index].y = pScreenInfo->dwInitialY - GetSystemMetrics(SM_YVIRTUALSCREEN);
+
+  ErrorF("Screen %d added at virtual desktop coordinate (%d,%d).\n",
+         index, dixScreenOrigins[index].x, dixScreenOrigins[index].y);
+
 #if CYGDEBUG || YES
   winDebug ("winScreenInit - returning\n");
 #endif
@@ -245,6 +256,25 @@ winScreenInit (int index,
   return TRUE;
 }
 
+static Bool
+winCreateScreenResources(ScreenPtr pScreen)
+{
+  winScreenPriv(pScreen);
+  Bool result;
+
+  result = pScreenPriv->pwinCreateScreenResources(pScreen);
+
+  /* Now the screen bitmap has been wrapped in a pixmap,
+     add that to the Shadow framebuffer */
+  if (!shadowAdd(pScreen, pScreen->devPrivate,
+		 pScreenPriv->pwinShadowUpdate, NULL, 0, 0))
+    {
+      ErrorF ("winCreateScreenResources - shadowAdd () failed\n");
+      return FALSE;
+    }
+
+  return result;
+}
 
 /* See Porting Layer Definition - p. 20 */
 Bool
@@ -360,22 +390,6 @@ winFinishScreenInitFB (int index,
   pScreen->blockData = pScreen;
   pScreen->wakeupData = pScreen;
 
-#ifdef XWIN_MULTIWINDOWEXTWM
-  /*
-   * Setup acceleration for multi-window external window manager mode.
-   * To be compatible with the Damage extension, this must be done
-   * before calling miDCInitialize, which calls DamageSetup.
-   */
-  if (pScreenInfo->fMWExtWM)
-    {
-      if (!RootlessAccelInit (pScreen))
-        {
-          ErrorF ("winFinishScreenInitFB - RootlessAccelInit () failed\n");
-          return FALSE;
-        }
-    }
-#endif
-
 #ifdef RENDER
   /* Render extension initialization, calls miPictureInit */
   if (!fbPictureInit (pScreen, NULL, 0))
@@ -428,15 +442,18 @@ winFinishScreenInitFB (int index,
       )
     {
 #if CYGDEBUG
-      winDebug ("winFinishScreenInitFB - Calling shadowInit ()\n");
+      winDebug ("winFinishScreenInitFB - Calling shadowSetup ()\n");
 #endif
-      if (!shadowInit (pScreen,
-		       pScreenPriv->pwinShadowUpdate,
-		       NULL))
+      if (!shadowSetup(pScreen))
 	{
-	  ErrorF ("winFinishScreenInitFB - shadowInit () failed\n");
+	  ErrorF ("winFinishScreenInitFB - shadowSetup () failed\n");
 	  return FALSE;
 	}
+
+      /* Wrap CreateScreenResources so we can add the screen pixmap
+         to the Shadow framebuffer after it's been created */
+      pScreenPriv->pwinCreateScreenResources = pScreen->CreateScreenResources;
+      pScreen->CreateScreenResources = winCreateScreenResources;
     }
 
 #ifdef XWIN_MULTIWINDOWEXTWM
@@ -478,9 +495,7 @@ winFinishScreenInitFB (int index,
       WRAP(UnrealizeWindow);
       WRAP(PositionWindow);
       WRAP(ChangeWindowAttributes);
-#ifdef SHAPE
       WRAP(SetShape);
-#endif
 
       /* Assign rootless window procedures to be top level procedures */
       pScreen->CreateWindow = winCreateWindowRootless;
@@ -489,9 +504,7 @@ winFinishScreenInitFB (int index,
       /*pScreen->ChangeWindowAttributes = winChangeWindowAttributesRootless;*/
       pScreen->RealizeWindow = winMapWindowRootless;
       pScreen->UnrealizeWindow = winUnmapWindowRootless;
-#ifdef SHAPE
       pScreen->SetShape = winSetShapeRootless;
-#endif
 
       /* Undefine the WRAP macro, as it is not needed elsewhere */
 #undef WRAP
@@ -523,9 +536,7 @@ winFinishScreenInitFB (int index,
       WRAP(ResizeWindow);
       WRAP(MoveWindow);
       WRAP(CopyWindow);
-#ifdef SHAPE
       WRAP(SetShape);
-#endif
 
       /* Assign multi-window window procedures to be top level procedures */
       pScreen->CreateWindow = winCreateWindowMultiWindow;
@@ -539,9 +550,7 @@ winFinishScreenInitFB (int index,
       pScreen->ResizeWindow = winResizeWindowMultiWindow;
       pScreen->MoveWindow = winMoveWindowMultiWindow;
       pScreen->CopyWindow = winCopyWindowMultiWindow;
-#ifdef SHAPE
       pScreen->SetShape = winSetShapeMultiWindow;
-#endif
 
       /* Undefine the WRAP macro, as it is not needed elsewhere */
 #undef WRAP
